@@ -12,6 +12,9 @@ pub struct CmdDurationConfig<'a> {
     pub disabled: bool,
     pub show_notifications: bool,
     pub min_time_to_notify: i64,
+
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub notification_timeout: Option<u32>,
 }
 
 impl<'a> Default for CmdDurationConfig<'a> {
@@ -24,6 +27,7 @@ impl<'a> Default for CmdDurationConfig<'a> {
             disabled: false,
             show_notifications: false,
             min_time_to_notify: 45_000,
+            notification_timeout: None,
         }
     }
 }
