@@ -7,6 +7,7 @@ use starship_module_config_derive::ModuleConfig;
 pub struct GitMetricsConfig<'a> {
     pub added_style: &'a str,
     pub deleted_style: &'a str,
+    pub only_nonzero_diffs: bool,
     pub format: &'a str,
     pub disabled: bool,
 }
@@ -16,7 +17,8 @@ impl<'a> Default for GitMetricsConfig<'a> {
         GitMetricsConfig {
             added_style: "bold green",
             deleted_style: "bold red",
-            format: "[+$added]($added_style) [-$deleted]($deleted_style) ",
+            only_nonzero_diffs: true,
+            format: "([+$added]($added_style) )([-$deleted]($deleted_style) )",
             disabled: true,
         }
     }
