@@ -11,7 +11,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         return None;
     }
 
-    let shell = context.shell;
+    let shell = &context.shell;
 
     let parsed = StringFormatter::new(config.format).and_then(|formatter| {
         formatter
@@ -26,6 +26,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                     Shell::Tcsh => Some(config.tcsh_indicator),
                     Shell::Nu => Some(config.nu_indicator),
                     Shell::Xonsh => Some(config.xonsh_indicator),
+                    Shell::Cmd => Some(config.cmd_indicator),
                     Shell::Unknown => Some(config.unknown_indicator),
                 },
                 _ => None,
@@ -43,6 +44,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
                 "elvish_indicator" => Some(Ok(config.elvish_indicator)),
                 "tcsh_indicator" => Some(Ok(config.tcsh_indicator)),
                 "xonsh_indicator" => Some(Ok(config.xonsh_indicator)),
+                "cmd_indicator" => Some(Ok(config.cmd_indicator)),
                 "unknown_indicator" => Some(Ok(config.unknown_indicator)),
                 _ => None,
             })
@@ -314,6 +316,35 @@ mod tests {
         assert_eq!(expected, actual);
     }
 
+    #[test]
+    fn test_cmd_default_format() {
+        let expected = Some(format!("{} ", Color::White.bold().paint("cmd")));
+        let actual = ModuleRenderer::new("shell")
+            .shell(Shell::Cmd)
+            .config(toml::toml! {
+                [shell]
+                disabled = false
+            })
+            .collect();
+
+        assert_eq!(expected, actual);
+    }
+
+    #[test]
+    fn test_cmd_custom_format() {
+        let expected = Some(format!("{} ", Color::Cyan.bold().paint("cmd")));
+        let actual = ModuleRenderer::new("shell")
+            .shell(Shell::Cmd)
+            .config(toml::toml! {
+                [shell]
+                cmd_indicator = "[cmd](bold cyan)"
+                disabled = false
+            })
+            .collect();
+
+        assert_eq!(expected, actual);
+    }
+
     #[test]
     fn test_custom_format_conditional_indicator_match() {
         let expected = Some(format!("{} ", "B"));
